@@ -71,7 +71,7 @@ class TimeseriesFlattener:  # pylint: disable=too-many-instance-attributes
         ):
             self.cache.prediction_times_df = prediction_times_df
         elif not self.cache.prediction_times_df.equals(prediction_times_df):
-            log.warning(
+            log.info(
                 "Overriding prediction_times_df in cache with prediction_times_df passed to init",
             )
             self.cache.prediction_times_df = prediction_times_df
@@ -79,7 +79,7 @@ class TimeseriesFlattener:  # pylint: disable=too-many-instance-attributes
         for attr in ("pred_time_uuid_col_name", "timestamp_col_name", "id_col_name"):
             if hasattr(self.cache, attr) and getattr(self.cache, attr) is not None:
                 if getattr(self.cache, attr) != getattr(self, attr):
-                    log.warning(
+                    log.info(
                         f"Overriding {attr} in cache with {attr} passed to init of flattened dataset",
                     )
                     setattr(self.cache, attr, getattr(self, attr))
@@ -447,7 +447,7 @@ class TimeseriesFlattener:  # pylint: disable=too-many-instance-attributes
         This checks that all the dataframes are aligned before
         concatenation.
         """
-        for _ in range(50):
+        for _ in range(5000):
             random_index = random.randint(0, len(dfs[0]) - 1)
             for feature_df in dfs[1:]:
                 if dfs[0].index[random_index] != feature_df.index[random_index]:
@@ -503,8 +503,6 @@ class TimeseriesFlattener:  # pylint: disable=too-many-instance-attributes
                 ),
             )
 
-        log.info("Processing complete, concatenating")
-
         self._concatenate_flattened_timeseries(
             flattened_predictor_dfs=flattened_predictor_dfs,
         )
@@ -666,7 +664,7 @@ class TimeseriesFlattener:  # pylint: disable=too-many-instance-attributes
         for spec in self.unprocessed_specs.outcome_specs:
             # Handle incident specs separately, since their operations can be vectorised,
             # making them much faster
-            if spec.incident:
+            if hasattr(spec, "incident") and spec.incident:
                 self._add_incident_outcome(
                     outcome_spec=spec,
                 )
